pyhsm.exception.YHSM_Error

Package pyhsm :: Module exception :: Class YHSM_Error |
[frames] | no frames]

# Class YHSM_Error

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                                  YHSM_Error

Known Subclasses:
  - YHSM_CommandFailed
  - , YHSM_InputTooLong
  - , YHSM_InputTooShort
  - , YHSM_WrongInputSize
  - , YHSM_WrongInputType

Base class for YHSM exceptions in this package.

Instance Methods
__init__(self, reason) x.__init__(...) initializes x; see help(type(x)) for signature |
__str__(self) str(x) |
Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Instance Variables
string | reason = `None` explanation of the error

Properties
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Method Details

### __init__(self, reason) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### __str__(self) (Informal representation operator) |
str(x) Overrides: object.__str__ (inherited documentation)